ContainsValidator class final

Inheritance
Mixed-in types

Constructors

ContainsValidator(String contains, {bool caseSensitive = true, String? errorMessage})
A validator that checks if a value contains a specified string. This validator is used to validate strings and other types that have a length property. It returns an error message if the value does not contain the specified string. The contains parameter specifies the desired string that the value should contain. Example usage:
const

Properties

caseSensitive bool
The caseSensitive parameter determines whether the comparison should be case-sensitive or not.
final
contains String
A validator that checks if a value contains a specified string.
final
errorMessage String?
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getErrorMessage(String message, [String? replacement]) String
Returns the error message with optional replacement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String? value) String?
Validates the given value and returns an error message if the value is invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
override