contains property

String contains
final

A validator that checks if a value contains a specified string.

The contains parameter specifies the desired string that the value should contain.

Implementation

final String contains;