A validator that checks if a value ends with a specified string.
This validator is used to validate strings and other types that have a length property.
It returns an error message if the value does not end with the specified string.
The endWith parameter specifies the desired string that the value should end with.
Example usage: