endWith property

String endWith
final

A validator that checks if a value ends with a specified string.

The endWith parameter specifies the desired string that the value should end with.

Implementation

final String endWith;