EqualToValidator class final

Inheritance
Mixed-in types

Constructors

EqualToValidator(String equalTo, {bool caseSensitive = true, bool useTrim = false, String? errorMessage})
A validator that checks if a value is equal to another value. This validator is used to validate strings and other types that have a length property. It returns an error message if the value is not equal to another value. Example usage:
const

Properties

caseSensitive bool
The caseSensitive parameter determines whether the comparison should be case-sensitive or not.
final
equalTo String
The equalTo parameter specifies the string that the value being validated should be equal to.
final
errorMessage String?
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useTrim bool
The useTrim parameter determines whether the comparison should ignore string leading and trailing whitespace or not.
final

Methods

getErrorMessage(String message, [String? replacement]) String
Returns the error message with optional replacement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String? value) String?
Validates the given value and returns an error message if the value is invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
override