maxWordCount property

int maxWordCount
final

The maximum word count that the value must have. The maxWordCount is the maximum word count that the value must have.

Implementation

final int maxWordCount;