minWordCount property

int minWordCount
final

The minimum word count that the value must have. The minWordCount is the minimum word count that the value must have.

Implementation

final int minWordCount;