caseSensitive property
The caseSensitive parameter determines whether the comparison should be case-sensitive or not.
Implementation
final bool caseSensitive;
The caseSensitive parameter determines whether the comparison should be case-sensitive or not.
final bool caseSensitive;