notEndWith property
The notEndWith parameter specifies the desired string that the value should not end with.
Implementation
final String notEndWith;
The notEndWith parameter specifies the desired string that the value should not end with.
final String notEndWith;