notEqualTo property
The notEqualTo parameter specifies the string that the value being validated should not be equal to.
Implementation
final String notEqualTo;
The notEqualTo parameter specifies the string that the value being validated should not be equal to.
final String notEqualTo;