notStartWith property
The notStartWith parameter specifies the undesired string that the value should not start with.
Implementation
final String notStartWith;
The notStartWith parameter specifies the undesired string that the value should not start with.
final String notStartWith;