RegularExpressionValidator class final

Inheritance
Mixed-in types

Constructors

RegularExpressionValidator(RegExp regExp, [String? errorMessage])
A validator that checks if a value matches a specified regular expression.
const

Properties

errorMessage String?
finalinherited
hashCode int
The hash code for this object.
no setteroverride
regExp RegExp
The regular expression to match the value against. The regExp parameter specifies the regular expression to match the value against.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getErrorMessage(String message, [String? replacement]) String
Returns the error message with optional replacement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String? value) String?
Validates the given value and returns an error message if the value is invalid.
override

Operators

operator ==(Object other) bool
The equality operator.
override