startWith property

String startWith
final

A validator that checks if a value starts with a specified string.

The startWith parameter specifies the desired string that the value should start with.

Implementation

final String startWith;