MaxWordCountValidator class final
- Inheritance
-
- Object
- EasyValidator
- MaxWordCountValidator
- Mixed-in types
Constructors
- MaxWordCountValidator(int maxWordCount, [String? errorMessage])
-
A validator that checks if the number of words in a value is less than or equal to a specified maximum word count.
const
Properties
- errorMessage → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxWordCount → int
-
The maximum word count that the value must have.
The maxWordCount is the maximum word count that the value must have.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getErrorMessage(
String message, [String? replacement]) → String -
Returns the error message with optional replacement.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String? value) → String? -
Validates the given
valueand returns an error message if the value is invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override