maxWordCount property
The maximum word count that the value must have. The maxWordCount is the maximum word count that the value must have.
Implementation
final int maxWordCount;
The maximum word count that the value must have. The maxWordCount is the maximum word count that the value must have.
final int maxWordCount;