minWordCount property
The minimum word count that the value must have. The minWordCount is the minimum word count that the value must have.
Implementation
final int minWordCount;
The minimum word count that the value must have. The minWordCount is the minimum word count that the value must have.
final int minWordCount;