NotContainsValidator class
A validator that checks if a string does not contain a specified substring.
- Inheritance
-
- Object
- EasyValidator
- NotContainsValidator
- Mixed-in types
Constructors
- NotContainsValidator(String notContains, {bool caseSensitive = true, String? errorMessage})
-
Creates a NotContainsValidator instance.
const
Properties
- caseSensitive → bool
-
The caseSensitive parameter determines whether the comparison should be case-sensitive or not.
final
- errorMessage → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- notContains → String
-
The substring that the value should not contain.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getErrorMessage(
String message, [String? replacement]) → String -
Returns the error message with optional replacement.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String? value) → String? -
Validates the given
valueand returns an error message if the value is invalid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override